summaryrefslogtreecommitdiffstats
path: root/src/import/generic/memory/lib/utils
diff options
context:
space:
mode:
Diffstat (limited to 'src/import/generic/memory/lib/utils')
-rw-r--r--src/import/generic/memory/lib/utils/shared/mss_generic_consts.H29
1 files changed, 19 insertions, 10 deletions
diff --git a/src/import/generic/memory/lib/utils/shared/mss_generic_consts.H b/src/import/generic/memory/lib/utils/shared/mss_generic_consts.H
index 5cafd98b..4bd2ceac 100644
--- a/src/import/generic/memory/lib/utils/shared/mss_generic_consts.H
+++ b/src/import/generic/memory/lib/utils/shared/mss_generic_consts.H
@@ -202,7 +202,10 @@ enum generic_ffdc_codes
SET_SI_ODT_WR = 0x1059,
SET_SI_ODT_RD = 0x1060,
SET_SI_GEARDOWN_MODE = 0x1061,
- PRE_DATA_ENGINE_CTOR = 0x1062
+ PRE_DATA_ENGINE_CTOR = 0x1062,
+ SET_DRAM_GEN_METADATA = 0x1063,
+ SET_DIMM_TYPE_METADATA = 0x1064,
+ SET_DIMM_POS_METADATA = 0x1065,
};
///
@@ -607,16 +610,17 @@ struct procTraits<proc_type::AXONE>
};
///
/// @brief Trait classes for proc_type
///
-template< proc_type P >
-class procTraits;
+template< mc_type MC >
+class mcTypeTraits;
///
/// @brief Trait classes for proc_type - NIMBUS specialization
///
template< >
-struct procTraits<proc_type::NIMBUS>
+struct mcTypeTraits<mc_type::NIMBUS>
{
enum
{
@@ -632,15 +636,20 @@ struct procTraits<proc_type::NIMBUS>
};
///
/// @brief Trait classes for proc_type - AXONE specialization
///
-/// TODO: Need to add mc_type
template< >
-struct procTraits<proc_type::AXONE>
+struct mcTypeTraits<mc_type::EXPLORER>
{
enum
{
- EXP_PORTS_PER_OCMB = 1,
+ MC_PER_PROC = 2,
+ MI_PER_MC = 2,
+ MCC_PER_MI = 2,
+ OMI_PER_MCC = 2,
+ OCMB_PER_OMI = 1,
+ PORTS_PER_OCMB = 1,
+ DIMMS_PER_PORT = 2,
};
};
OpenPOWER on IntegriCloud
@@ -607,16 +610,17 @@ struct procTraits<proc_type::AXONE>
};
///
-/// @brief Trait classes for proc_type
+/// @brief Trait classes for mc_type
+/// @tparam MC the mc_type
///
@@ -607,16 +610,17 @@ struct procTraits<proc_type::AXONE>
///
-/// @brief Trait classes for proc_type - NIMBUS specialization
+/// @brief Trait classes for mc_type - NIMBUS specialization
///
template< >
@@ -632,15 +636,20 @@ struct procTraits<proc_type::NIMBUS>
};
///
-/// @brief Trait classes for proc_type - AXONE specialization
+/// @brief Trait classes for mc_type - EXPLORER specialization
///